summaryrefslogtreecommitdiffstats
path: root/wgpu/src/widget/canvas/layer.rs
diff options
context:
space:
mode:
authorLibravatar Héctor Ramón Jiménez <hector0193@gmail.com>2020-03-10 06:12:06 +0100
committerLibravatar Héctor Ramón Jiménez <hector0193@gmail.com>2020-03-10 06:12:06 +0100
commite4fbca59b4b9478c9c5fa5eec9ebe31dc93412ad (patch)
tree237d2e5dd29c2d0f05f2b68f829425bb480b8ce7 /wgpu/src/widget/canvas/layer.rs
parent6151c528241d0a6ece88e6e664df1b50f8174ecb (diff)
parent5a91b52ef4066701d82a897b44a3f90412f210d2 (diff)
downloadiced-e4fbca59b4b9478c9c5fa5eec9ebe31dc93412ad.tar.gz
iced-e4fbca59b4b9478c9c5fa5eec9ebe31dc93412ad.tar.bz2
iced-e4fbca59b4b9478c9c5fa5eec9ebe31dc93412ad.zip
Merge branch 'master' into feature/panes-widget
Diffstat (limited to 'wgpu/src/widget/canvas/layer.rs')
-rw-r--r--wgpu/src/widget/canvas/layer.rs14
1 files changed, 7 insertions, 7 deletions
diff --git a/wgpu/src/widget/canvas/layer.rs b/wgpu/src/widget/canvas/layer.rs
index 82d647bb..a46b7fb1 100644
--- a/wgpu/src/widget/canvas/layer.rs
+++ b/wgpu/src/widget/canvas/layer.rs
@@ -3,23 +3,23 @@ mod cache;
pub use cache::Cache;
-use crate::triangle;
-
+use crate::Primitive;
use iced_native::Size;
+
use std::sync::Arc;
/// A layer that can be presented at a [`Canvas`].
///
/// [`Canvas`]: ../struct.Canvas.html
pub trait Layer: std::fmt::Debug {
/// Draws the [`Layer`] in the given bounds and produces [`Mesh2D`] as a
/// result.
///
/// The [`Layer`] may choose to store the produced [`Mesh2D`] locally and
/// only recompute it when the bounds change, its contents change, or is
/// otherwise explicitly cleared by other means.
///
/// [`Layer`]: trait.Layer.html
- /// [`Mesh2D`]: ../../../triangle/struct.Mesh2D.html
- fn draw(&self, bounds: Size) -> Arc<triangle::Mesh2D>;
+ /// [`Primitive`]: ../../../enum.Primitive.html
+ fn draw(&self, bounds: Size) -> Arc<Primitive>;
}
@@ -3,23 +3,23 @@ mod cache;
/// [`Canvas`]: ../struct.Canvas.html
pub trait Layer: std::fmt::Debug {
- /// Draws the [`Layer`] in the given bounds and produces [`Mesh2D`] as a
- /// result.
+ /// Draws the [`Layer`] in the given bounds and produces a [`Primitive`] as
+ /// a result.
///
@@ -3,23 +3,23 @@ mod cache;
///
- /// The [`Layer`] may choose to store the produced [`Mesh2D`] locally and
+ /// The [`Layer`] may choose to store the produced [`Primitive`] locally and
/// only recompute it when the bounds change, its contents change, or is
/// otherwise explicitly cleared by other means.